// markov.cpp
#include <cmath>
#include "Markov.h"

void Markov::setInitialValues(vector<double>& y){
    Kout = 4.5;
    vold = -1000.0;
    vhold = -80.0;
    vpulse = 20.0;
    vhold2 = -50.0;

    for(int i = 0; i< NUM_OF_HERG_STATES ; i++){
        y[i] = 0.0;
    }
/* more modern way of writhing for loop
    for (vector<double>::iterator i = y.begin() ; i != y.end(); ++i){
        *i = 0.0;        
    }
*/
    y[0] = 1.0;
};

void Markov::rhs(double t, vector<double> y, vector<double>& dy){

    double v;
    if(t<50.0){
        v = vhold;
    }else if(t<150.0){
        v = vpulse;
    }else{
        v =  vhold2;
    }
    if(v != vold){
        aa = 66.5E-3 * exp(0.05547153 * (v-36.0));
        ain = 2.172;
        a = 55.5E-3 * exp(0.05547153 * (v - 12.0));
        b = 2.357E-3 * exp(-0.036588 * v);
        bin = 1.077;
        bb = 2.9357E-3 * exp(-0.02158 * v);
        ai = 0.439 * exp(-0.02352*(v + 25.0)) * 4.5/Kout;
        bi = 0.656 * exp(0.000942 * v) * pow(4.5/Kout, 0.3);
        mu =(ai*bb)/bi;
        vold = v;
    }
    dy[0] = -a*y[0] + b*y[1];
    dy[1] = -(ain + b)*y[1] + a*y[0] + bin*y[2];
    dy[2] = -(bin + 2.0*aa)*y[2] + ain*y[1] + bb*y[3] + mu*y[4];
    dy[3] = -(bb + bi)*y[3] + aa*y[2] + ai*y[4];
    dy[4] = -(mu + ai)*y[4] + aa*y[2] + bi*y[3];
}
